@@ -1,5 +1,7 @@
 from typing import Iterable, Sized
 
+import pytest
+
 from text2array import Batch, BucketIterator
 
 
@@ -32,3 +34,21 @@ def test_shuffle_bucket(rng):
     bs1 = [list(b) for b in iter_]
     bs2 = [list(b) for b in iter_]
     assert bs1 != bs2
+
+
+def test_sort_bucket():
+    samples = [{"n": n} for n in range(100)]
+    bucket_key = lambda s: s["n"] // 10
+
+    iter_ = BucketIterator(
+        samples, bucket_key, batch_size=3, sort_bucket=True, sort_bucket_by=lambda s: -s["n"]
+    )
+
+    for b in iter_:
+        for s, s_ in zip(b, b[1:]):
+            assert s["n"] > s_["n"]
+
+
+def test_shuffle_and_sort_bucket():
+    with pytest.warns(UserWarning):
+        BucketIterator([], len, shuffle_bucket=True, sort_bucket=True)
